@@ -92,7 +92,7 @@ public abstract class AbstractMessagingAccountAction implements AJAXActionServic
     public AJAXRequestResult perform(final AJAXRequestData requestData, final ServerSession session) throws OXException {
         try {
             return doIt(requestData, session);
-        } catch (final JSONException x) {
+        } catch (JSONException x) {
             throw MessagingExceptionCodes.JSON_ERROR.create(x,x.toString());
         }
     }
@@ -146,7 +146,7 @@ public abstract class AbstractMessagingAccountAction implements AJAXActionServic
         }
         try {
             return Integer.parseInt(obj.toString());
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             return -1;
         }
     }
