@@ -163,7 +163,7 @@ public class RssProperties {
             if (Strings.isNotEmpty(token)) {
                 try {
                     tmp.add(Integer.valueOf(token.trim()));
-                } catch (NumberFormatException e) {
+                } catch (@SuppressWarnings("unused") NumberFormatException e) {
                     // Ignore
                 }
             }
@@ -183,7 +183,24 @@ public class RssProperties {
         URI uri;
         try {
             uri = new URI(uriString);
-            return !isAllowed(uri.getPort()) || isBlacklisted(uri.getHost()) || !isAllowedScheme(uri.getScheme()) || !isValid(uri);
+            int port = uri.getPort();
+            if (port < 0) {
+                String scheme = Strings.asciiLowerCase(uri.getScheme());
+                if (Strings.isEmpty(scheme)) {
+                    // Assume HTTP as default
+                    port = 80;
+                } else {
+                    scheme = scheme.trim();
+                    if ("http".equals(scheme)) {
+                        port = 80;
+                    } else if ("https".equals(scheme)) {
+                        port = 443;
+                    }  else {
+                        port = 80;
+                    }
+                }
+            }
+            return !isAllowed(port) || isBlacklisted(uri.getHost()) || !isAllowedScheme(uri.getScheme()) || !isValid(uri);
         } catch (URISyntaxException e) {
             org.slf4j.LoggerFactory.getLogger(RssProperties.class).debug("Given feed URL \"{}\" appears not to be valid.", uriString, e);
             return true;
